package org.apache.bcel.classfile;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;

/* loaded from: org_apache_bcel_classfile.jar:org/apache/bcel/classfile/ModuleExports.class */
public final class ModuleExports implements Cloneable, Node {
    private final int exportsIndex;
    private final int exportsFlags;
    private final int exportsToCount;
    private final int[] exportsToIndex;

    /* JADX INFO: Access modifiers changed from: package-private */
    public ModuleExports(DataInput file) throws IOException {
        this.exportsIndex = file.readUnsignedShort();
        this.exportsFlags = file.readUnsignedShort();
        this.exportsToCount = file.readUnsignedShort();
        this.exportsToIndex = new int[this.exportsToCount];
        for (int i = 0; i < this.exportsToCount; i++) {
            this.exportsToIndex[i] = file.readUnsignedShort();
        }
    }

    @Override // org.apache.bcel.classfile.Node
    public void accept(Visitor v) {
        v.visitModuleExports(this);
    }

    public ModuleExports copy() {
        try {
            return (ModuleExports) clone();
        } catch (CloneNotSupportedException e) {
            return null;
        }
    }

    public void dump(DataOutputStream file) throws IOException {
        file.writeShort(this.exportsIndex);
        file.writeShort(this.exportsFlags);
        file.writeShort(this.exportsToCount);
        for (int entry : this.exportsToIndex) {
            file.writeShort(entry);
        }
    }

    public String toString() {
        return "exports(" + this.exportsIndex + ", " + this.exportsFlags + ", " + this.exportsToCount + ", ...)";
    }

    public String toString(ConstantPool constantPool) {
        StringBuilder buf = new StringBuilder();
        String packageName = constantPool.constantToString(this.exportsIndex, (byte) 20);
        buf.append(Utility.compactClassName(packageName, false));
        buf.append(", ").append(String.format("%04x", Integer.valueOf(this.exportsFlags)));
        buf.append(", to(").append(this.exportsToCount).append("):\n");
        for (int index : this.exportsToIndex) {
            String moduleName = constantPool.getConstantString(index, (byte) 19);
            buf.append("      ").append(Utility.compactClassName(moduleName, false)).append("\n");
        }
        return buf.substring(0, buf.length() - 1);
    }
}
